@@ -1,6 +1,5 @@
 M = Manifold(4, 'M')
 X = M.chart('t x y z'); t,x,y,z = X[:]
-v = M.vector_field(name='v')
-v[:] = (t/8)**2, -t*y/4, t*x/4, t*z/4
+v = M.vector_field((t/8)**2, -t*y/4, t*x/4, t*z/4, name='v')
 g = v.plot(ambient_coords=(x, y), fixed_coords={t: 1, z: 0})
 sphinx_plot(g)
\ No newline at end of file
